=======
History
=======



0.6.0 (2017-06-28)
------------------

* remote progress reporting and logging to SushiBar (MVP version)
* New API based on the SuchiChef classes
* Support existing old-API chefs in compatibility mode




0.5.13 (2017-06-15)
-------------------

* the last stable release before SushiBar functionality was added
* renamed --do-not-activate argument to --stage



0.1.0 (2016-09-30)
------------------

* First release on PyPI.
